@@ -3,8 +3,9 @@
 from __future__ import unicode_literals
 
 from ._vulcan import Vulcan
+from .hebe import VulcanHebe, Keystore, Account
 
-__version__ = "1.2.0"
+__version__ = "1.3.0"
 __doc__ = "Unofficial API for UONET+ e-register"
 
-__all__ = ["Vulcan"]
+__all__ = ["Vulcan", "VulcanHebe", "Keystore", "Account"]
