@@ -5,14 +5,12 @@ from related import IntegerField, StringField, immutable
 
 @immutable
 class Subject:
-    """
-    School subject
+    """School subject
 
-    Attributes:
-        id (:class:`int`): Subject ID
-        name (:class:`str`): Subject full name
-        short (:class:`str`): Short name of the subject
-        position (:class:`int`) Position of the subject in subjects list
+    :var int ~.id: Subject ID
+    :var str ~.name: Subject full name
+    :var str ~.short: Short name of the subject
+    :var int ~.position: Position of the subject in subjects list
     """
 
     id = IntegerField(key="Id")
